Class: WMCtrl::Desktop

Inherits:
DataHash show all
Defined in:
lib/wmctrl/wmctrl.rb

Instance Method Summary collapse

Methods inherited from DataHash

#initialize, #method_missing

Constructor Details

This class inherits a constructor from WMCtrl::DataHash

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class WMCtrl::DataHash

Instance Method Details

#geometry_height ⇒ Object



56
57
58
# File 'lib/wmctrl/wmctrl.rb', line 56

def geometry_height
  self[:geometry][1]
end

#geometry_width ⇒ Object



52
53
54
# File 'lib/wmctrl/wmctrl.rb', line 52

def geometry_width
  self[:geometry][0]
end

#workarea_height ⇒ Integer

Returns Height of workarea.

Returns:

  • (Integer) —

    Height of workarea



76
77
78
# File 'lib/wmctrl/wmctrl.rb', line 76

def workarea_height
  self[:workarea][3]
end

#workarea_width ⇒ Integer

Returns Width of workarea.

Returns:

  • (Integer) —

    Width of workarea



71
72
73
# File 'lib/wmctrl/wmctrl.rb', line 71

def workarea_width
  self[:workarea][2]
end

#workarea_x ⇒ Integer

Returns X coordinate of Top left corner of workarea.

Returns:

  • (Integer) —

    X coordinate of Top left corner of workarea



61
62
63
# File 'lib/wmctrl/wmctrl.rb', line 61

def workarea_x
  self[:workarea][0]
end

#workarea_y ⇒ Integer

Returns Y coordinate of Top left corner of workarea.

Returns:

  • (Integer) —

    Y coordinate of Top left corner of workarea



66
67
68
# File 'lib/wmctrl/wmctrl.rb', line 66

def workarea_y
  self[:workarea][1]
end